c     Evaluation routine for 2-dimensional vibrationally averaged
c     version of He-CO potential described in "A hierarchical family of
c     three dimensional potential energy surfaces for He--CO",
c     J. Chem. Phys., 2005, by Kirk A. Peterson and George C. McBane.

c     This is a simple driver for the kpcoef routine, which does almost
c     all of the work.  For the 3d version, see hecokp3d.f.


c     Arguments: 

c     R: distance, in bohr, between He atom and CO center of
c     mass.  

C     CT: cosine of the angle between the vector pointing from CO center
C     of mass to He and the vector pointing from C to O.  CT=1
C     corresponds to the He-O-C linear arrangement.

c     Return value: He-CO interaction energy, in cm-1, averaged
c     over the vibrational wavefunction of CO.  You can choose
c     which vibrational state of CO by commenting out
c     all but one of the DATA lines below.

c     Author: G. C. McBane, 21 June 2002

      double precision function hecokp2d(R, CT)
      implicit none
      double precision R, CT

c     Common block keep2 communicates with kpcoef routine,
c     sets pivot for Taylor expansion in CO internuclear distance.
c     This value should be changed if new moments r1v, etc. are
c     calculated for use in vibrational averaging below.

      common /keep2/ r1e    
      double precision r1e
      data r1e /2.1322d0/
      save /keep2/


c     set number of terms in polynomial expansion in r1 
c     (CO internuclear distance)
       integer numterms
       parameter (numterms = 4)

c     Moments of (r1-r1e) for CO vibrational functions
      double precision rv,r2v,r3v

c..   following values from sinc dvr eigenfunctions using 
c     CO RKR + Huxley pef (Lagrange interp.)  Uncomment
c     one line to give desired vibrational state of CO.
c.. v=0
       data rv,r2v,r3v/0.00776d0,0.00414d0,0.00012d0/
c.. v=1
c      data rv,r2v,r3v/0.02332d0,0.01284d0,0.00077d0/
c.. v=2
c      data rv,r2v,r3v/0.03907d0,0.02216d0,0.00211d0/
       save rv, r2v, r3v

       integer ncall
       data ncall /1/
       save ncall

       double precision vr1coef(numterms)

       if (ncall.eq.1) then
c     initialize
          call kpcoef(R, CT, vr1coef, numterms)
          ncall = 2
       end if

c     now evaluate potential coefficients and average over v


       call kpcoef(R, CT, vr1coef, -1)
       hecokp2d = vr1coef(1) + rv*vr1coef(2) + 
     1      r2v*vr1coef(3) + r3v*vr1coef(4)

       return
       end





